# SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later
"""AlexNet_, to be fine-tuned. Pre-trained on ImageNet_.

This configuration contains a version of AlexNet_ (c.f. `TorchVision's
page <alexnet-pytorch_>`_), modified for a variable number of outputs
(defaults to 1).

N.B.: The output layer is **always** initialized from scratch.
"""

import torch.nn
import torch.optim
import torchvision.transforms

import mednet.classify.models.alexnet
import mednet.models.transforms

model = mednet.classify.models.alexnet.Alexnet(
    loss_type=torch.nn.BCEWithLogitsLoss,
    optimizer_type=torch.optim.Adam,
    optimizer_arguments=dict(lr=0.0001),
    pretrained=True,
    model_transforms=[
        mednet.models.transforms.SquareCenterPad(),
        torchvision.transforms.v2.Resize(512, antialias=True),
        mednet.models.transforms.RGB(),
    ],
)
