# SPDX-FileCopyrightText: Copyright © 2024 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later

"""HED Network for Segmentation.

Reference: [XIE-2015]_
"""

import torch.optim
import torchvision.transforms

import mednet.models.transforms
import mednet.segment.models.hed
import mednet.segment.models.losses

model = mednet.segment.models.hed.HED(
    loss_type=mednet.segment.models.losses.MultiSoftJaccardBCELogitsLoss,
    loss_arguments=dict(alpha=0.7),  # 0.7 BCE + 0.3 Jaccard
    optimizer_type=torch.optim.Adam,
    optimizer_arguments=dict(lr=0.01),
    model_transforms=[
        mednet.models.transforms.SquareCenterPad(),
        torchvision.transforms.v2.Resize(512, antialias=True),
        mednet.models.transforms.RGB(),
    ],
    pretrained=False,
)
