# SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later

"""Define specialized data typing for segmentation tasks."""

import typing
from typing import TypedDict

import torch

from ...data.typing import RawDataLoader


class SegmentationData(TypedDict):
    """Type for segmentation data."""

    image: torch.Tensor
    target: torch.Tensor
    mask: torch.Tensor


Sample: typing.TypeAlias = tuple[SegmentationData, typing.Mapping[str, typing.Any]]


class SegmentationRawDataLoader(RawDataLoader):
    """Loader object that handles samples and labels from storage."""

    def __init__(self):
        super().__init__()

    def sample(self, _: tuple[str, str, str | None]) -> Sample:
        """Load whole samples from media.

        Parameters
        ----------
        _
            Information about the sample to load. Implementation dependent.
        """

        raise NotImplementedError("You must implement the `sample()` method")
